@@ -6,7 +6,6 @@ use Test::More;
 use Catalyst::Runtime 5.80;
 
 use Catalyst qw/
-    -Debug
     +CatalystX::Fastly::Role::Response
 
     /;
@@ -23,13 +22,6 @@ __PACKAGE__->config(
 # Start the application
 __PACKAGE__->setup();
 
-sub cdn_purge_now {
-    my ( $c, $args ) = @_;
-
-    is( $args->{keys}->[0], 'BAR', '1st purge_now key is BAR' );
-
-}
-
 1;
 
 # sub cdn_purge_now {
