@@ -2,7 +2,6 @@ package Test::App::Controller::Root;
 
 use Moose;
 use namespace::autoclean;
-use Catalyst::Action::RenderView;    # do autopreq picks it up
 
 BEGIN { extends 'Catalyst::Controller' }
 
@@ -58,6 +57,14 @@ sub no_cdn_some_browser : Path('cdn_no_cache_browser_cache') {
     $c->response->body('Browser cacheing, CDN no cache');
 }
 
+sub no_cdn_browser_not_set : Path('cdn_no_browser_cache_not_set') {
+    my ( $self, $c ) = @_;
+
+    $c->cdn_never_cache(1);
+
+    $c->response->body('Browser cacheing not set, CDN no cache');
+}
+
 sub some_keys : Path('some_surrogate_keys') {
     my ( $self, $c ) = @_;
 
@@ -66,8 +73,6 @@ sub some_keys : Path('some_surrogate_keys') {
     $c->response->body('surrogate keys');
 }
 
-sub end : ActionClass('RenderView') { }
-
 __PACKAGE__->meta->make_immutable;
 
 1;
